==> inpostshipping-1.28.0.zip: inpostshipping/src/Hook/OrderHistory.php <==
<?php
/**
 * Copyright since 2021 InPost S.A.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the EUPL-1.2 or later.
 * You may not use this work except in compliance with the Licence.
 *
 * You may obtain a copy of the Licence at:
 * https://joinup.ec.europa.eu/software/page/eupl
 * It is also bundled with this package in the file LICENSE.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Licence is distributed on an AS IS basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions
 * and limitations under the Licence.
 *
 * @author    InPost S.A.
 * @copyright Since 2021 InPost S.A.
 * @license   https://joinup.ec.europa.eu/software/page/eupl
 */

namespace InPost\Shipping\Hook;

use InPost\Shipping\Configuration\SzybkieZwrotyConfiguration;
use InPost\Shipping\Hook\Traits\GetPointDataByCartIdTrait;
use InPost\Shipping\Presenter\PointAddressPresenter;

class OrderHistory extends AbstractHook
{
    use GetPointDataByCartIdTrait;

    const HOOK_LIST = [
        'displayOrderDetail',
    ];

    /**
     * @param array{order: \Order} $params
     *
     * @return string
     */
    public function hookDisplayOrderDetail(array $params)
    {
        /** @var SzybkieZwrotyConfiguration $configuration */
        $configuration = $this->module->getService('inpost.shipping.configuration.szybkie_zwroty');

        $this->context->smarty->assign([
            'returnFormUrl' => $configuration->getOrderReturnFormUrl(),
            'inpost_point_address' => $this->presentPickupPointAddress($params['order']),
        ]);

        return $this->shopContext->is17()
            ? $this->module->display($this->module->name, 'views/templates/hook/order-detail.tpl')
            : $this->module->display($this->module->name, 'views/templates/hook/16/order-detail.tpl');
    }

    /**
     * @return string|null
     */
    private function presentPickupPointAddress(\Order $order)
    {
        if (null === $point = $this->getPointDataByCartId($order->id_cart)) {
            return null;
        }

        /** @var PointAddressPresenter $addressPresenter */
        $addressPresenter = $this->module->getService('inpost.shipping.presenter.point_address');

        return $addressPresenter->present($point);
    }
}

==> inpostshipping-2.15.0.zip: inpostshipping/src/Hook/OrderHistory.php <==
<?php
/**
 * Copyright since 2021 InPost S.A.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the EUPL-1.2 or later.
 * You may not use this work except in compliance with the Licence.
 *
 * You may obtain a copy of the Licence at:
 * https://joinup.ec.europa.eu/software/page/eupl
 * It is also bundled with this package in the file LICENSE.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Licence is distributed on an AS IS basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions
 * and limitations under the Licence.
 *
 * @author    InPost S.A.
 * @copyright Since 2021 InPost S.A.
 * @license   https://joinup.ec.europa.eu/software/page/eupl
 */

namespace InPost\Shipping\Hook;

use InPost\Shipping\Configuration\SzybkieZwrotyConfiguration;
use InPost\Shipping\Hook\Traits\GetPointDataByCartIdTrait;
use InPost\Shipping\Presenter\PointAddressPresenter;

class OrderHistory extends AbstractHook
{
    use GetPointDataByCartIdTrait;

    protected const HOOK_LIST = [
        'displayOrderDetail',
    ];

    /**
     * @param array{order: \Order} $params
     *
     * @return string
     */
    public function hookDisplayOrderDetail(array $params)
    {
        /** @var SzybkieZwrotyConfiguration $configuration */
        $configuration = $this->module->getService('inpost.shipping.configuration.szybkie_zwroty');

        $this->context->smarty->assign([
            'returnFormUrl' => $configuration->getOrderReturnFormUrl(),
            'inpost_point_address' => $this->presentPickupPointAddress($params['order']),
        ]);

        return $this->module->display($this->module->name, 'views/templates/hook/order-detail.tpl');
    }

    /**
     * @return string|null
     */
    private function presentPickupPointAddress(\Order $order)
    {
        if (null === $point = $this->getPointDataByCartId($order->id_cart)) {
            return null;
        }

        /** @var PointAddressPresenter $addressPresenter */
        $addressPresenter = $this->module->getService('inpost.shipping.presenter.point_address');

        return $addressPresenter->present($point);
    }
}
